Class: Spree::Admin::BulkOperationsController
- Inherits:
-
BaseController
- Object
- BaseController
- BaseController
- Spree::Admin::BulkOperationsController
- Defined in:
- app/controllers/spree/admin/bulk_operations_controller.rb
Instance Method Summary collapse
-
#new ⇒ Object
GET /admin/bulk_operations/new?kind=:action_key&table_key=:table_key Generic bulk modal action that reads configuration from BulkAction.
Methods included from BreadcrumbConcern
#add_breadcrumb_icon_instance_var
Instance Method Details
#new ⇒ Object
GET /admin/bulk_operations/new?kind=:action_key&table_key=:table_key Generic bulk modal action that reads configuration from BulkAction
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 |
# File 'app/controllers/spree/admin/bulk_operations_controller.rb', line 6 def new @table_key = params[:table_key]&.to_sym @bulk_action = find_bulk_action(params[:kind], @table_key) if @bulk_action.nil? head :not_found return end @title = @bulk_action.resolve_title @body = @bulk_action.resolve_body @form_partial = @bulk_action.form_partial @form_partial_locals = @bulk_action.form_partial_locals || {} @button_text = @bulk_action. @button_class = @bulk_action. end |